pub struct MarketSubscribeRequest {
pub assets_ids: Vec<String>,
pub operation: &'static str,
pub custom_feature_enabled: bool,
}Expand description
Incremental market-channel subscribe request sent after the initial session subscribe.
Wire format: {"assets_ids": [...], "operation": "subscribe"}
When custom_feature_enabled is true, enables new market and market resolved events.
Fields
assets_ids: Vec<String>operation: &'static strcustom_feature_enabled: boolTrait Implementations
Sourceimpl Debug for MarketSubscribeRequest
impl Debug for MarketSubscribeRequest